..
  # SPDX-FileCopyrightText: Copyright (c) 2022 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
  # SPDX-License-Identifier: Apache-2.0
  #
  # Licensed under the Apache License, Version 2.0 (the "License");
  # you may not use this file except in compliance with the License.
  # You may obtain a copy of the License at
  #
  # http://www.apache.org/licenses/LICENSE-2.0
  #
  # Unless required by applicable law or agreed to in writing, software
  # distributed under the License is distributed on an "AS IS" BASIS,
  # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  # See the License for the specific language governing permissions and
  # limitations under the License.

.. _v0.1.0-prealpha:

PreAlpha
========

CV-CUDA-0.1.0 is the first release of CV-CUDA. This release is for evaluation purposes only.

Release Highlights
------------------

This CV-CUDA release includes the following key features:

* Core components including Image and Tensor with Batch support
* Utilities to help write CUDA kernels
* 6 Operators - Reformat, Resize, Custom Crop, Normalize, PadAndStack, ConvertTo
* Tensor interoperability with pytorch/gpu, Image interoperability with pytorch/gpu, pillow/cpu, opencv/cpu
* Python bindings
* Sample applications
* API documentation

Compatibility
-------------
This section highlights the compute stack CV-CUDA has been tested on

* Ubuntu x86 >= 20.04
* CUDA driver >= 11.7

The Sample applications based on TensorRT have been tested with TensorRT >= 8.5

Known Issues
------------
* There will be few updates in the Tensor API, Image Formats and Operator names in the next release
* Limitations in the usage of the operators which are described in the API documentation

License
-------
Nvidia Software Evaluation License
